@@ -526,3 +526,36 @@ def insert_to_table_from_dataframe(
     table_ref = get_table_ref(client, dataset_id, table_name)
     table = client.get_table(table_ref)
     return client.insert_rows_from_dataframe(table, data)
+
+
+def load_to_table_from_dataframe(
+    service_account_file: str,
+    dataset_id: str,
+    table_name: str,
+    write_disposition: str,
+    data: pd.DataFrame(),
+):
+    """
+    Loads dataframe to the specified table. Returns list of errors for each row
+
+    :param service_account_file: relative location of service account file
+    :param dataset_id: Bigquery dataset id
+    :param table_name: Table name to insert rows
+    :param write_disposition: write disposition of query results
+    :param data: Data to be inserted into the table
+    :return This instance:
+    :raises: ValueError: If a usable parquet engine cannot be found. This method requires :mod:`pyarrow` to be installed
+    """
+    if write_disposition not in WRITE_DISPOSITIONS:
+        raise ValueError(
+            "Invalid write disposition: {}. Acceptable values are WRITE_APPEND, WRITE_TRUNCATE, and WRITE_EMPTY".format(
+                write_disposition
+            )
+        )
+    client = connect(service_account_file=service_account_file)
+    job_config = bigquery.LoadJobConfig()
+    table_ref = get_table_ref(client, dataset_id, table_name)
+    job_config.write_disposition = write_disposition
+    return client.load_table_from_dataframe(
+        data, table_ref, job_config=job_config
+    ).result()
